diff --git a/htdocs/core/class/html.formticket.class.php b/htdocs/core/class/html.formticket.class.php
index a34861e17d6..be515a2abf3 100644
--- a/htdocs/core/class/html.formticket.class.php
+++ b/htdocs/core/class/html.formticket.class.php
@@ -1,7 +1,7 @@
* Copyright (C) 2016 Christophe Battarel
- * Copyright (C) 2019 Frédéric France
+ * Copyright (C) 2019-2022 Frédéric France
* Copyright (C) 2021 Juanjo Menent
* Copyright (C) 2021 Alexandre Spangaro
*
@@ -53,6 +53,11 @@ class FormTicket
*/
public $track_id;
+ /**
+ * @var string trackid
+ */
+ public $trackid;
+
/**
* @var int ID
*/
@@ -89,8 +94,12 @@ class FormTicket
public $withusercreate; // to show name of creating user in form
public $withcreatereadonly;
- public $withref; // to show ref field
+ /**
+ * @var int withextrafields
+ */
+ public $withextrafields;
+ public $withref; // to show ref field
public $withcancel;
public $type_code;